# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.tone_touch_type import ToneTouchType

from mozart_api.configuration import Configuration


class ToneTouch(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"x": "ToneTouchType", "y": "ToneTouchType"}

    attribute_map = {"x": "x", "y": "y"}

    def __init__(
        self,
        x: Optional[ToneTouchType] = None,
        y: Optional[ToneTouchType] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """ToneTouch - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._x = None
        self._y = None
        self.discriminator = None

        if x is not None:
            self.x = x
        if y is not None:
            self.y = y

    @property
    def x(self):
        # type: () -> ToneTouchType
        """Gets the x of this ToneTouch.  # noqa: E501


        :return: The x of this ToneTouch.  # noqa: E501
        :rtype: ToneTouchType
        """
        return self._x

    @x.setter
    def x(self, x):
        # type: (ToneTouchType) -> None
        """Sets the x of this ToneTouch.


        :param x: The x of this ToneTouch.  # noqa: E501
        :type x: ToneTouchType
        :rtype: None
        """

        self._x = x

    @property
    def y(self):
        # type: () -> ToneTouchType
        """Gets the y of this ToneTouch.  # noqa: E501


        :return: The y of this ToneTouch.  # noqa: E501
        :rtype: ToneTouchType
        """
        return self._y

    @y.setter
    def y(self, y):
        # type: (ToneTouchType) -> None
        """Sets the y of this ToneTouch.


        :param y: The y of this ToneTouch.  # noqa: E501
        :type y: ToneTouchType
        :rtype: None
        """

        self._y = y

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ToneTouch):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ToneTouch):
            return True

        return self.to_dict() != other.to_dict()
