# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional


from mozart_api.configuration import Configuration


class VideoTimings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "horizontal_resolution": "int",
        "interlaced": "bool",
        "refresh_rate": "float",
        "vertical_resolution": "int",
    }

    attribute_map = {
        "horizontal_resolution": "horizontalResolution",
        "interlaced": "interlaced",
        "refresh_rate": "refreshRate",
        "vertical_resolution": "verticalResolution",
    }

    def __init__(
        self,
        horizontal_resolution: Optional[int] = None,
        interlaced: Optional[bool] = None,
        refresh_rate: Optional[float] = None,
        vertical_resolution: Optional[int] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """VideoTimings - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._horizontal_resolution = None
        self._interlaced = None
        self._refresh_rate = None
        self._vertical_resolution = None
        self.discriminator = None

        if horizontal_resolution is not None:
            self.horizontal_resolution = horizontal_resolution
        if interlaced is not None:
            self.interlaced = interlaced
        if refresh_rate is not None:
            self.refresh_rate = refresh_rate
        if vertical_resolution is not None:
            self.vertical_resolution = vertical_resolution

    @property
    def horizontal_resolution(self):
        # type: () -> int
        """Gets the horizontal_resolution of this VideoTimings.  # noqa: E501


        :return: The horizontal_resolution of this VideoTimings.  # noqa: E501
        :rtype: int
        """
        return self._horizontal_resolution

    @horizontal_resolution.setter
    def horizontal_resolution(self, horizontal_resolution):
        # type: (int) -> None
        """Sets the horizontal_resolution of this VideoTimings.


        :param horizontal_resolution: The horizontal_resolution of this VideoTimings.  # noqa: E501
        :type horizontal_resolution: int
        :rtype: None
        """

        self._horizontal_resolution = horizontal_resolution

    @property
    def interlaced(self):
        # type: () -> bool
        """Gets the interlaced of this VideoTimings.  # noqa: E501


        :return: The interlaced of this VideoTimings.  # noqa: E501
        :rtype: bool
        """
        return self._interlaced

    @interlaced.setter
    def interlaced(self, interlaced):
        # type: (bool) -> None
        """Sets the interlaced of this VideoTimings.


        :param interlaced: The interlaced of this VideoTimings.  # noqa: E501
        :type interlaced: bool
        :rtype: None
        """

        self._interlaced = interlaced

    @property
    def refresh_rate(self):
        # type: () -> float
        """Gets the refresh_rate of this VideoTimings.  # noqa: E501


        :return: The refresh_rate of this VideoTimings.  # noqa: E501
        :rtype: float
        """
        return self._refresh_rate

    @refresh_rate.setter
    def refresh_rate(self, refresh_rate):
        # type: (float) -> None
        """Sets the refresh_rate of this VideoTimings.


        :param refresh_rate: The refresh_rate of this VideoTimings.  # noqa: E501
        :type refresh_rate: float
        :rtype: None
        """

        self._refresh_rate = refresh_rate

    @property
    def vertical_resolution(self):
        # type: () -> int
        """Gets the vertical_resolution of this VideoTimings.  # noqa: E501


        :return: The vertical_resolution of this VideoTimings.  # noqa: E501
        :rtype: int
        """
        return self._vertical_resolution

    @vertical_resolution.setter
    def vertical_resolution(self, vertical_resolution):
        # type: (int) -> None
        """Sets the vertical_resolution of this VideoTimings.


        :param vertical_resolution: The vertical_resolution of this VideoTimings.  # noqa: E501
        :type vertical_resolution: int
        :rtype: None
        """

        self._vertical_resolution = vertical_resolution

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VideoTimings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VideoTimings):
            return True

        return self.to_dict() != other.to_dict()
