# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mozart_api
from mozart_api.api.sound_api import SoundApi  # noqa: E501
from mozart_api.rest import ApiException


class TestSoundApi(unittest.TestCase):
    """SoundApi unit test stubs"""

    def setUp(self):
        self.api = mozart_api.api.sound_api.SoundApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_activate_listening_mode(self):
        """Test case for activate_listening_mode

        Activate a listening mode  # noqa: E501
        """
        pass

    def test_get_active_listening_mode(self):
        """Test case for get_active_listening_mode

        Get the active listening mode  # noqa: E501
        """
        pass

    def test_get_current_volume(self):
        """Test case for get_current_volume

        Get the current volume state  # noqa: E501
        """
        pass

    def test_get_listening_mode_set(self):
        """Test case for get_listening_mode_set

        Get available listening modes that match the current role (standalone or multichannel).   # noqa: E501
        """
        pass

    def test_get_sound_features(self):
        """Test case for get_sound_features

        Get available sound features that match the current role (standalone or multichannel).   # noqa: E501
        """
        pass

    def test_get_volume_settings(self):
        """Test case for get_volume_settings

        Get the current volume settings for default and maximum volume level  # noqa: E501
        """
        pass

    def test_set_current_volume_level(self):
        """Test case for set_current_volume_level

        Set the current volume level  # noqa: E501
        """
        pass

    def test_set_sound_settings_adjustments_bass(self):
        """Test case for set_sound_settings_adjustments_bass

        Update the sound settings adjustments for bass  # noqa: E501
        """
        pass

    def test_set_sound_settings_adjustments_directivity(self):
        """Test case for set_sound_settings_adjustments_directivity

        Update the sound settings adjustments for directivity  # noqa: E501
        """
        pass

    def test_set_sound_settings_adjustments_loudness(self):
        """Test case for set_sound_settings_adjustments_loudness

        Update the sound settings adjustments for loudness  # noqa: E501
        """
        pass

    def test_set_sound_settings_adjustments_treble(self):
        """Test case for set_sound_settings_adjustments_treble

        Update the sound settings adjustments for treble  # noqa: E501
        """
        pass

    def test_set_volume_mute(self):
        """Test case for set_volume_mute

        Set the volume mute state  # noqa: E501
        """
        pass

    def test_set_volume_settings(self):
        """Test case for set_volume_settings

        Set the current volume settings for default and maximum volume level  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
