# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mozart_api
from mozart_api.api.playback_api import PlaybackApi  # noqa: E501
from mozart_api.rest import ApiException


class TestPlaybackApi(unittest.TestCase):
    """PlaybackApi unit test stubs"""

    def setUp(self):
        self.api = mozart_api.api.playback_api.PlaybackApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_activate_preset(self):
        """Test case for activate_preset

        Trigger a preset  # noqa: E501
        """
        pass

    def test_add_to_queue(self):
        """Test case for add_to_queue

        Add an element to the queue  # noqa: E501
        """
        pass

    def test_get_available_sources(self):
        """Test case for get_available_sources

        Get all the available sources  # noqa: E501
        """
        pass

    def test_get_playback_state(self):
        """Test case for get_playback_state

        Get the current playback state  # noqa: E501
        """
        pass

    def test_get_settings_queue(self):
        """Test case for get_settings_queue

        Get the current queue settings  # noqa: E501
        """
        pass

    def test_post_clear_queue(self):
        """Test case for post_clear_queue

        Clear the queue  # noqa: E501
        """
        pass

    def test_post_playback_command(self):
        """Test case for post_playback_command

        Send a specific playback command to the product  # noqa: E501
        """
        pass

    def test_post_uri_source(self):
        """Test case for post_uri_source

        Set the URI from which sound is streamed  # noqa: E501
        """
        pass

    def test_seek_to_position(self):
        """Test case for seek_to_position

        Seek to position in stream  # noqa: E501
        """
        pass

    def test_set_active_source(self):
        """Test case for set_active_source

        Set the active source  # noqa: E501
        """
        pass

    def test_set_settings_queue(self):
        """Test case for set_settings_queue

        Set queue settings  # noqa: E501
        """
        pass

    def test_start_deezer_flow(self):
        """Test case for start_deezer_flow

        Play users flow. If no provided user id it will play the flow connected to the active account  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
