# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mozart_api
from mozart_api.models.paired_remote import PairedRemote  # noqa: E501
from mozart_api.rest import ApiException


class TestPairedRemote(unittest.TestCase):
    """PairedRemote unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PairedRemote
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # model = mozart_api.models.paired_remote.PairedRemote()  # noqa: E501
        if include_optional:
            return PairedRemote(address="0", battery_level=0, name="0")
        else:
            return PairedRemote(
                address="0",
                name="0",
            )

    def testPairedRemote(self):
        """Test PairedRemote"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
