# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mozart_api
from mozart_api.models.web_socket_event_hdmi_video_format_signal import (
    WebSocketEventHdmiVideoFormatSignal,
)  # noqa: E501
from mozart_api.rest import ApiException


class TestWebSocketEventHdmiVideoFormatSignal(unittest.TestCase):
    """WebSocketEventHdmiVideoFormatSignal unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test WebSocketEventHdmiVideoFormatSignal
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # model = mozart_api.models.web_socket_event_hdmi_video_format_signal.WebSocketEventHdmiVideoFormatSignal()  # noqa: E501
        if include_optional:
            return WebSocketEventHdmiVideoFormatSignal(
                event_data=mozart_api.models.hdmi_video_format.HdmiVideoFormat(
                    pixel_format=mozart_api.models.video_pixel_format.VideoPixelFormat(
                        bitdepth="bit8",
                        chroma_subsample="yCbCr444RGB",
                        colorimetry="rGB",
                        full_range=True,
                    ),
                    v_ic=0,
                    video_timings=mozart_api.models.video_timings.VideoTimings(
                        horizontal_resolution=56,
                        interlaced=True,
                        refresh_rate=1.337,
                        vertical_resolution=56,
                    ),
                ),
                event_type="0",
            )
        else:
            return WebSocketEventHdmiVideoFormatSignal()

    def testWebSocketEventHdmiVideoFormatSignal(self):
        """Test WebSocketEventHdmiVideoFormatSignal"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
