# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mozart_api
from mozart_api.api.scenes_api import ScenesApi  # noqa: E501
from mozart_api.rest import ApiException


class TestScenesApi(unittest.TestCase):
    """ScenesApi unit test stubs"""

    def setUp(self):
        self.api = mozart_api.api.scenes_api.ScenesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_all_scenes(self):
        """Test case for get_all_scenes

        Get a list of configured scenes  # noqa: E501
        """
        pass

    def test_post_scene_match_trigger(self):
        """Test case for post_scene_match_trigger

        Trigger the first scene with same non null objects provided in the SceneMatch object  # noqa: E501
        """
        pass

    def test_post_scene_trigger(self):
        """Test case for post_scene_trigger

        Trigger a specific scene  # noqa: E501
        """
        pass

    def test_run_provided_scene(self):
        """Test case for run_provided_scene

        Run provided scene  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
