# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mozart_api
from mozart_api.api.beolink_api import BeolinkApi  # noqa: E501
from mozart_api.rest import ApiException


class TestBeolinkApi(unittest.TestCase):
    """BeolinkApi unit test stubs"""

    def setUp(self):
        self.api = mozart_api.api.beolink_api.BeolinkApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_beolink_available_listeners(self):
        """Test case for get_beolink_available_listeners

        Get available listeners  # noqa: E501
        """
        pass

    def test_get_beolink_join_result(self):
        """Test case for get_beolink_join_result

        Get Beolink join result, test-endpoint  # noqa: E501
        """
        pass

    def test_get_beolink_listeners(self):
        """Test case for get_beolink_listeners

        Get joined peers  # noqa: E501
        """
        pass

    def test_get_beolink_peers(self):
        """Test case for get_beolink_peers

        Get discovered peers  # noqa: E501
        """
        pass

    def test_get_beolink_self(self):
        """Test case for get_beolink_self

        Get information about this device  # noqa: E501
        """
        pass

    def test_join_beolink_peer(self):
        """Test case for join_beolink_peer

        Join multi-room experience  # noqa: E501
        """
        pass

    def test_join_latest_beolink_experience(self):
        """Test case for join_latest_beolink_experience

        Trigger touch to join  # noqa: E501
        """
        pass

    def test_post_beolink_allstandby(self):
        """Test case for post_beolink_allstandby

        Broadcast an all standby event to turn all Beolink devices off  # noqa: E501
        """
        pass

    def test_post_beolink_expand(self):
        """Test case for post_beolink_expand

        Expand the current active experience  # noqa: E501
        """
        pass

    def test_post_beolink_leave(self):
        """Test case for post_beolink_leave

        Leave the ongoing experience (disconnect this device from remote)  # noqa: E501
        """
        pass

    def test_post_beolink_unexpand(self):
        """Test case for post_beolink_unexpand

        Unexpand (disconnect) a device from the multiroom session  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
