# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mozart_api
from mozart_api.api.software_update_api import SoftwareUpdateApi  # noqa: E501
from mozart_api.rest import ApiException


class TestSoftwareUpdateApi(unittest.TestCase):
    """SoftwareUpdateApi unit test stubs"""

    def setUp(self):
        self.api = mozart_api.api.software_update_api.SoftwareUpdateApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_softwareupdate_status(self):
        """Test case for get_softwareupdate_status

        Get the current software update status  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
