# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mozart_api
from mozart_api.api.power_api import PowerApi  # noqa: E501
from mozart_api.rest import ApiException


class TestPowerApi(unittest.TestCase):
    """PowerApi unit test stubs"""

    def setUp(self):
        self.api = mozart_api.api.power_api.PowerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_battery_state(self):
        """Test case for get_battery_state

        Get battery state of the product  # noqa: E501
        """
        pass

    def test_get_power_state(self):
        """Test case for get_power_state

        Get power state of the product  # noqa: E501
        """
        pass

    def test_post_standby(self):
        """Test case for post_standby

        Put the device in standby  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
